==> Cosmos.uv3.02.tar.gz: Tracking/cifDead.f <==
C            cifDead;  see if too low energy 
c
        subroutine cifDead(a, icon)
        implicit none

#include  "Ztrack.h"
#include  "Zcode.h"
#include  "Ztrackv.h"
#include  "Ztrackp.h"
#include  "Zobs.h"
#include  "Zobsp.h"
c
      record /track/ a   ! input.  a track to be examined
      integer icon !   output.  0 => alive  else dead

      real*8  ke
      integer jold

      icon = 0
      ke = a.p.fm.p(4) - a.p.mass

        if(a.p.code .eq. kphoton ) then
           if( ke .lt.  KEminCas) then
              icon = 1
           elseif(ke .lt. KEminObs .and. a.asflag .ne. 0) then  ! 95/08/17
              icon = 1                                          ! //
           elseif( ke  .lt. KEminCas2) then
              call rndsw(jold, 2)
           endif   
        elseif(a.p.code .eq. kelec) then
c           if( .not. ObserveAS ) then
c              if(ke .lt. KEminObs ) then
c                 icon = 1
c              elseif(ke .lt. KEminObs2) then
c                 call rndsw(jold, 2)
c              endif
c           else
              if(ke .lt. KEminCas) then             ! 95/08/17
	          icon = 1                          !  //
              elseif(ke .lt. KEminObs .and. a.asflag .ne. 0) then
                 icon = 1
              elseif(ke .lt. KEminCas2) then
                 call rndsw(jold, 2)
              endif
c           endif
        elseif(a.p.code .eq. knuc) then
           if( a.p.subcode .eq. antip) then
c               can annihilate
              if( a.p.fm.p(4)  .lt. KEmin) then
                 icon = 1
              elseif( a.p.fm.p(4) .lt. KEmin2) then
                 call rndsw(jold, 2)
              endif
           else
              if( ke .lt.  KEmin) then
                 icon = 1
              elseif(ke .lt. KEmin2) then
                 call rndsw(jold, 2)   
              endif
           endif
        elseif(a.p.code .eq. kpion  .or.
     *         a.p.code .eq. kkaon  .or.
     *         a.p.code .eq. kmuon) then
c               can decay
           if(a.p.fm.p(4) .lt. KEmin) then
              icon = 1
           elseif(a.p.fm.p(4) .lt. KEmin2) then
              call rndsw(jold, 2)
           endif
        else
           if(ke .lt.  KEmin) then
              icon = 1
           elseif(ke .lt. KEmin2) then
              call rndsw(jold, 2)
           endif
        endif
        if(PathLimit .lt. a.t) then
           icon = 1
        endif
        if( a.where .gt. NoOfSites2) then
           call rndsw(jold, 2)
        endif
        end

==> Cosmos.uv4.10.tar.gz: Tracking/cifDead.f <==
C            cifDead;  see if too low energy 
c
        subroutine cifDead(a, icon)
        implicit none

#include  "Ztrack.h"
#include  "Zcode.h"
#include  "Ztrackv.h"
#include  "Ztrackp.h"
#include  "Zobs.h"
#include  "Zobsp.h"
c
      record /track/ a   ! input.  a track to be examined
      integer icon !   output.  0 => alive  else dead

      real*8  ke
      integer jold

      icon = 0
      ke = a.p.fm.p(4) - a.p.mass

        if(a.p.code .eq. kphoton .or.  a.p.code .eq. kelec ) then
           if( ke  .lt. KEminCas2) then
              call rndsw(jold, 2)
           endif
           if( ke .lt.  KEminCas) then
              icon = 1
           endif   
        elseif(a.p.code .eq. knuc) then
           if( a.p.subcode .eq. antip) then
c               can annihilate
              if( a.p.fm.p(4)  .lt. KEmin) then
                 icon = 1
              endif
              if( a.p.fm.p(4) .lt. KEmin2) then
                 call rndsw(jold, 2)
              endif
           else
              if( ke .lt.  KEmin) then
                 icon = 1
              endif
              if(ke .lt. KEmin2) then
                 call rndsw(jold, 2)   
              endif
           endif
        elseif(a.p.code .eq. kpion  .or.
     *         a.p.code .eq. kkaon  .or.
     *         a.p.code .eq. kmuon) then
c               can decay
           if(a.p.fm.p(4) .lt. KEmin) then
              icon = 1
           endif
           if(a.p.fm.p(4) .lt. KEmin2) then
              call rndsw(jold, 2)
           endif
        else
           if(ke .lt.  KEmin) then
              icon = 1
           endif
           if(ke .lt. KEmin2) then
              call rndsw(jold, 2)
           endif
        endif
        if(PathLimit .lt. a.t) then
           icon = 1
        endif
        if( a.where .gt. EndLevel2) then
           call rndsw(jold, 2)
        endif
        end
